@@ -171,8 +171,19 @@ dBodySetMaxAngularSpeed = loadOde('dBodySetMaxAngularSpeed', None, dBodyID, dRea
 dBodyGetGyroscopicMode = loadOde('dBodyGetGyroscopicMode', c_int32, dBodyID)
 dBodySetGyroscopicMode = loadOde('dBodySetGyroscopicMode', None, dBodyID, c_int32)
 dJointCreateBall = loadOde('dJointCreateBall', dJointID, dWorldID, dJointGroupID)
-dJointCreateHinge = loadOde('dJointCreateHinge', dJointID, dWorldID, dJointGroupID)
-dJointCreateSlider = loadOde('dJointCreateSlider', dJointID, dWorldID, dJointGroupID)
+
+def dJointCreateHinge(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreateHinge', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreateHinge', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
+
+def dJointCreateSlider(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreateSlider', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreateSlider', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
+
 dJointCreateContact = loadOde('dJointCreateContact', dJointID, dWorldID, dJointGroupID, POINTER(dContact))
 dJointCreateHinge2 = loadOde('dJointCreateHinge2', dJointID, dWorldID, dJointGroupID)
 dJointCreateUniversal = loadOde('dJointCreateUniversal', dJointID, dWorldID, dJointGroupID)
